This directory is used for testing MyPy type-checking against stub files
generated by bravado-types.  For each subdirectory, the tests will generate a
module based on the .json file, then invoke MyPy for each .py module in the
directory. The modules are annotated with comments indicating the expected MyPy
output, which are parsed and verified by the tests.
